@@ -331,6 +331,8 @@ def get_predictions(
     price_areas: List[str] = None,
     start: str = None,
     end: str = None,
+    ref_dt_start: str = None,
+    ref_dt_end: str = None,
     *,
     access_token: str = None,
 ) -> pd.DataFrame:
@@ -355,6 +357,10 @@ def get_predictions(
             The first datetime to fetch (inclusive). Returns all if None. Defaults to None.
         end (str, optional):
             The last datetime to fetch (exclusive). Returns all if None. Defaults to None.
+        ref_dt_start (pd.Timestamp, optional):
+            The earliest ref_dt to fetch (inclusive). Defaults to None.
+        ref_dt_end (pd.Timestamp, optional):
+            The latest ref_dt to fetch (exclusive). Defaults to None.
         access_token (str, optional): None - access token for the API
 
     Returns:
@@ -378,6 +384,12 @@ def get_predictions(
 
     query = {"start": start, "end": end}
 
+    if ref_dt_start is not None:
+        query["ref_dt_start"] = pd.to_datetime(ref_dt_start)
+
+    if ref_dt_end is not None:
+        query["ref_dt_end"] = pd.to_datetime(ref_dt_end)
+
     if series_ids is not None:
         query["series_ids"] = series_ids
 
@@ -395,7 +407,13 @@ def get_predictions(
         item.update(json_data)
         del item["json_data"]
 
-    return pd.DataFrame.from_dict(data)
+    df = pd.DataFrame.from_dict(data)
+
+    df["from_dt"] = pd.to_datetime(df["from_dt"], utc=True)
+    df["run_dt"] = pd.to_datetime(df["run_dt"], utc=True)
+    df["ref_dt"] = pd.to_datetime(df["ref_dt"], utc=True)
+
+    return df
 
 
 def list_series_price_areas(series_id: str, *, access_token: str = None):
